Index: kernel/arch/sparc64/src/start.S
===================================================================
--- kernel/arch/sparc64/src/start.S	(revision 45b26dad9e99feac8777a9787b017301df054794)
+++ kernel/arch/sparc64/src/start.S	(revision b44939b3e96b45459ade4081b45ffb74c843202e)
@@ -44,5 +44,5 @@
  * 
  * The registers are expected to be in this state:
  * - %o0 non-zero for the bootstrup processor, zero for application/secondary processors
  * - %o1 bootinfo structure address
  * - %o2 bootinfo structure size
@@ -57,6 +57,5 @@
 .global kernel_image_start
 kernel_image_start:
-	brz %o0, kernel_image_start		! block secondary processors
-	nop
+	mov %o0, %l7
 
 	/*
@@ -76,7 +75,9 @@
 	 * to the kernel bootinfo structure.
 	 */
+	brz %l7, 0f				! skip if you are not the bootstrap CPU
 	sethi %hi(bootinfo), %o0
 	call memcpy
 	or %o0, %lo(bootinfo), %o0
+0:
 
 	/*
@@ -226,4 +227,6 @@
 	wrpr %g0, 0, %tl
 
+	brz %l7, 2f				! skip if you are not the bootstrap CPU
+
 	call arch_pre_main
 	nop
@@ -44,5 +44,5 @@
  * 
  * The registers are expected to be in this state:
- * - %o0 non-zero for the bootstrup processor, zero for application/secondary processors
+ * - %o0 non-zero for the bootstrap processor, zero for application/secondary processors
  * - %o1 bootinfo structure address
  * - %o2 bootinfo structure size
